Module: CarrierWave::Processing::RMagick
- Defined in:
- lib/carrierwave-processing/rmagick.rb
Instance Method Summary collapse
-
#quality(percentage) ⇒ Object
Reduces the quality of the image to the percentage given.
-
#strip ⇒ Object
Strips out all embedded information from the image.
Instance Method Details
#quality(percentage) ⇒ Object
Reduces the quality of the image to the percentage given
14 15 16 17 18 19 20 |
# File 'lib/carrierwave-processing/rmagick.rb', line 14 def quality(percentage) manipulate! do |img| img.write(current_path){ self.quality = percentage } img = yield(img) if block_given? img end end |
#strip ⇒ Object
Strips out all embedded information from the image
5 6 7 8 9 10 11 |
# File 'lib/carrierwave-processing/rmagick.rb', line 5 def strip manipulate! do |img| img.strip! img = yield(img) if block_given? img end end |